Skip to contents

In silent mode, all user prompts are automatically confirmed. Be careful, this will skip the prompt to confirm operations on the live server.

Usage

api_silent(silent = F)

Arguments

silent

Boolen