Usage
default_values(df, colname, default)
Arguments
- df
A data frame
- colname
A column name as character value
- default
If the column is not present in the data frame, add it with the default value
Value
A data frame where the given column was added if necessary