Skip to contents

Check whether the provided vector contains only valid IRI fragments

Usage

epi_is_irifragment(value)

Arguments

value

The vector that will be checked.

Value

A vector of the same length as value, containg TRUE or FALSE.