Skip to contents

Add a row to the rows in the epi attribute

Usage

ram_add(df, rows, skip = FALSE)

Arguments

df

A tibble

rows

Crafted rows

skip

Whether to update the record or only use it as reference

Value

Epigraf tibble