Fetch entity data such as articles, projects or properties from the API
Source:R/fetch.R
api_fetch.RdReturns all data belonging to all entities matched by the params. The procedure corresponds to calling the index action with the columns parameter set to 0 in the Epigraf interface.
Usage
api_fetch(table, params = c(), db = NA, maxpages = 1)