In silent mode, all user prompts are automatically confirmed. Be careful, this will skip the prompt to confirm operations on the live server.
In silent mode, all user prompts are automatically confirmed. Be careful, this will skip the prompt to confirm operations on the live server.