R/fetch.R
db_fetch.Rd
Returns all data belonging to all entities matched by the params.
db_fetch(table, params = list(), db = NA)
The table name (e.g. "articles").
A named list of query conditions, passed to db_table.
The database name (character). Provide a character vector of dababase names to get and row bind data from multiple databases.