R/epi.R
epi_extract_wide.Rd
Select nested data from prefixed columns
epi_extract_wide(data, cols_prefix, cols_keep = c())
A data frame
All columns with the prefix will be selected, the prefix will be removed from the column name.
Convert the provided column names to underscored columns
A dataframe containing all columns with the prefix without the prefix