Returns a row with defined columns for each record matched by the params. The procedure corresponds to calling the index action in the Epigraf interface.
Returns a row with defined columns for each record matched by the params. The procedure corresponds to calling the index action in the Epigraf interface.